@@ -1,7 +1,5 @@
-import collections
-
-from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.inspection import inspect
+from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.properties import ColumnProperty
 
 from .config import ALLOWED_METHODS
@@ -28,7 +26,7 @@ class Model(object):
         return str(getattr(self, self.primary_key_field()))
 
     @classmethod
-    def _load_cols(cls):
+    def _load_columns(cls):
         """
 
         """
@@ -38,40 +36,40 @@ class Model(object):
         for i in cls.__dict__:
             if not (i.startswith('_') or i in cls.__hidden__):
                 col = getattr(cls, i)
-                if not isinstance(col, collections.Callable):
-                    if isinstance(col.comparator, ColumnProperty.Comparator):
-                        cls.__cols__[i] = col
-                        if col.primary_key:
-                            cls.__pks__.append(i)
+                if isinstance(col.comparator, ColumnProperty.Comparator):
+                    cls.__cols__[i] = col
+                    if col.primary_key:
+                        cls.__pks__.append(i)
 
     @classmethod
-    def _load_related(cls):
+    def _load_related(cls, **kwargs):
         """
 
         """
         cls.__rels__ = {}
+        pk_only = kwargs.get('pk_only') or False
 
         for r in inspect(cls).relationships:
-            if isinstance(r.argument, Mapper):
-                key = r.argument.class_.__name__
-                columns = r.argument.class_().columns()
-            else:
-                key = r.argument.__name__
-                columns = r.argument.columns()
+            try:
+                rel = r.argument.class_
+            except AttributeError:
+                rel = r.argument
 
+            key = rel.__name__
+            columns = rel().columns(pk_only and r.uselist)
             instance = getattr(cls, r.key)
             cls.__rels__.update({key: dict(instance=instance, columns=columns)})
 
     @classmethod
-    def columns(cls):
+    def columns(cls, pk_only=False):
         """
 
         :return:
         """
         if cls.__cols__ is None:
-            cls._load_cols()
+            cls._load_columns()
 
-        return cls.__cols__
+        return cls.__pks__ if pk_only else cls.__cols__
 
     @classmethod
     def required(cls):
@@ -119,19 +117,19 @@ class Model(object):
         :return:
         """
         if cls.__pks__ is None:
-            cls._load_cols()
+            cls._load_columns()
 
         return cls.__pks__[0]
 
     @classmethod
-    def related(cls, name=None):
+    def related(cls, name=None, **kwargs):
         """
 
         :param name:
         :return:
         """
         if not cls.__rels__:
-            cls._load_related()
+            cls._load_related(**kwargs)
 
         if name is None:
             return cls.__rels__
@@ -173,22 +171,30 @@ class Model(object):
 
         :return:
         """
+        related = {}
+        fields = []
+
+        for r in inspect(cls).relationships:
+            rel = r.argument.class_ if r.uselist else r.argument
+            related.update({rel.__name__: rel.__url__})
+
+        for col, c in cls.columns().items():
+            fields.append(dict(
+                name=col,
+                type=c.type.python_type.__name__,
+                key=c.primary_key,
+                nullable=c.nullable,
+                unique=c.unique,
+                description=c.comment
+            ))
+
         return dict(
             url=cls.__url__,
             name=cls.__name__,
             methods=list(cls.__methods__),
             description=cls.__description__ or cls.__table__.comment,
-            fields=[
-                dict(
-                    name=col,
-                    type=c.type.python_type.__name__,
-                    key=c.primary_key,
-                    autoincrement=c.autoincrement,
-                    nullable=c.nullable,
-                    unique=c.unique,
-                    description=c.comment
-                ) for col, c in cls.columns().items()
-            ]
+            related=related,
+            fields=fields
         )
 
     def to_dict(self, links=False):
@@ -224,19 +230,19 @@ class Model(object):
         :return:
         """
         link_dict = dict(self=self.resource_uri())
-
         for r in inspect(self.__class__).relationships:
-            if not r.uselist:
-                instance = getattr(self, r.key)
-                if instance:
-                    key = r.argument.__name__
-                    link_dict[key] = instance.resource_uri()
-            elif isinstance(r.argument, Mapper):
-                key = r.argument.class_.__name__
-                link_dict[key] = "{}{}".format(
-                    self.resource_uri(),
-                    r.argument.class_.__url__
-                )
+            if isinstance(r.argument, Mapper):
+                if r.uselist:
+                    key = r.argument.class_.__name__
+                    link_dict[key] = "{}{}".format(
+                        self.resource_uri(),
+                        r.argument.class_.__url__
+                    )
+                else:
+                    instance = getattr(self, r.key)
+                    if instance:
+                        key = r.argument.__name__
+                        link_dict[key] = instance.resource_uri()
 
         return link_dict
 
