@@ -1,5 +1,7 @@
 import pytest
+import flask
 
+from flask_errors_handler import ErrorHandler
 from . import create_app
 from . import assert_export
 
@@ -19,12 +21,35 @@ def test_app_runs(client):
     res = client.get('/')
     assert res.status_code == 404
 
+    # increase coverage
+    autocrud = client.application.extensions['autocrud']
+    assert isinstance(autocrud.blueprint, flask.Blueprint)
+    assert isinstance(autocrud.error_handler, ErrorHandler)
+    assert isinstance(autocrud.models, dict)
+    for m in autocrud.models.values():
+        assert print(m()) is None
+        assert isinstance(m.searchable(), list)
+
 
 def test_resources_list_json(client):
     res = client.get('/resources')
     assert res.status_code == 200
     assert res.headers.get('Content-Type') == 'application/json'
 
+    res = client.head('/artist')
+    assert res.status_code == 200
+    assert res.data == b''
+
+    res = client.get('/artist?_as_table')
+    assert res.status_code == 200
+    assert res.headers.get('Content-Type') == 'application/json'
+
+    res = client.get('/artist?_no_links')
+    data = res.get_json()
+    assert res.status_code == 200
+    assert res.headers.get('Content-Type') == 'application/json'
+    assert '_meta' not in data and '_links' not in data['ArtistList']
+
 
 def test_resources_list_xml(client):
     res = client.get(
@@ -81,6 +106,12 @@ def test_update(client):
     )
     assert res.status_code == 200
 
+    res = client.patch(
+        '/artist/10000000',
+        json={'Name': 'pippo3'}
+    )
+    assert res.status_code == 404
+
 
 def test_unprocessable_entity(client):
     res = client.post(
@@ -223,7 +254,7 @@ def test_export(client):
 
 
 def test_subresource(client):
-    res = client.get('/album/5/track?_extended')
+    res = client.get('/album/5/track?_related')
     assert res.status_code == 200
 
     data = res.get_json()['TrackList'][0]
@@ -236,3 +267,6 @@ def test_subresource(client):
         "Genre",
         "MediaType"
     ))
+
+    res = client.get('/album/5/notfound')
+    assert res.status_code == 404
